( cd usr/bin ; rm -rf emacs )
( cd usr/bin ; ln -sf emacs-19.28-with-x11 emacs )
( cd usr/lib/emacs ; rm -rf lock )
( cd usr/lib/emacs ; ln -sf /var/lock/emacs lock )
( cd usr/man/preformat/cat1 ; rm -rf ctags.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf etags.1.gz ctags.1.gz )
( cd usr/bin ; rm -rf etags )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/etags etags )
( cd usr/bin ; rm -rf ctags )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/ctags ctags )
( cd usr/bin ; rm -rf emacsclient )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/emacsclient emacsclient )
( cd usr/bin ; rm -rf b2m )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/b2m b2m )
( cd usr/bin ; rm -rf rcs-checkin )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/rcs-checkin rcs-checkin )
( cd usr/bin ; rm -rf emacs-19.28-with-x11 )
( cd usr/bin ; ln -sf /cdrom/live/usr/bin/emacs-19.28-with-x11 emacs-19.28-with-x11 )
( cd usr/info ; rm -rf cl.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/cl.gz cl.gz )
( cd usr/info ; rm -rf cl-1.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/cl-1.gz cl-1.gz )
( cd usr/info ; rm -rf cl-2.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/cl-2.gz cl-2.gz )
( cd usr/info ; rm -rf cl-3.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/cl-3.gz cl-3.gz )
( cd usr/info ; rm -rf cl-4.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/cl-4.gz cl-4.gz )
( cd usr/info ; rm -rf cl-5.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/cl-5.gz cl-5.gz )
( cd usr/info ; rm -rf cl-6.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/cl-6.gz cl-6.gz )
( cd usr/info ; rm -rf dired-x.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/dired-x.gz dired-x.gz )
( cd usr/info ; rm -rf emacs.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs.gz emacs.gz )
( cd usr/info ; rm -rf emacs-1.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-1.gz emacs-1.gz )
( cd usr/info ; rm -rf emacs-10.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-10.gz emacs-10.gz )
( cd usr/info ; rm -rf emacs-11.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-11.gz emacs-11.gz )
( cd usr/info ; rm -rf emacs-12.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-12.gz emacs-12.gz )
( cd usr/info ; rm -rf emacs-13.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-13.gz emacs-13.gz )
( cd usr/info ; rm -rf emacs-14.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-14.gz emacs-14.gz )
( cd usr/info ; rm -rf emacs-15.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-15.gz emacs-15.gz )
( cd usr/info ; rm -rf emacs-16.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-16.gz emacs-16.gz )
( cd usr/info ; rm -rf emacs-17.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-17.gz emacs-17.gz )
( cd usr/info ; rm -rf emacs-18.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-18.gz emacs-18.gz )
( cd usr/info ; rm -rf emacs-19.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-19.gz emacs-19.gz )
( cd usr/info ; rm -rf emacs-2.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-2.gz emacs-2.gz )
( cd usr/info ; rm -rf emacs-20.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-20.gz emacs-20.gz )
( cd usr/info ; rm -rf emacs-21.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-21.gz emacs-21.gz )
( cd usr/info ; rm -rf emacs-22.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-22.gz emacs-22.gz )
( cd usr/info ; rm -rf emacs-23.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-23.gz emacs-23.gz )
( cd usr/info ; rm -rf emacs-24.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-24.gz emacs-24.gz )
( cd usr/info ; rm -rf emacs-3.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-3.gz emacs-3.gz )
( cd usr/info ; rm -rf emacs-4.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-4.gz emacs-4.gz )
( cd usr/info ; rm -rf emacs-5.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-5.gz emacs-5.gz )
( cd usr/info ; rm -rf emacs-6.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-6.gz emacs-6.gz )
( cd usr/info ; rm -rf emacs-7.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-7.gz emacs-7.gz )
( cd usr/info ; rm -rf emacs-8.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-8.gz emacs-8.gz )
( cd usr/info ; rm -rf emacs-9.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/emacs-9.gz emacs-9.gz )
( cd usr/info ; rm -rf forms.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/forms.gz forms.gz )
( cd usr/info ; rm -rf gnus.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/gnus.gz gnus.gz )
( cd usr/info ; rm -rf gnus-1.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/gnus-1.gz gnus-1.gz )
( cd usr/info ; rm -rf gnus-2.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/gnus-2.gz gnus-2.gz )
( cd usr/info ; rm -rf gnus-3.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/gnus-3.gz gnus-3.gz )
( cd usr/info ; rm -rf info.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/info.gz info.gz )
( cd usr/info ; rm -rf sc.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/sc.gz sc.gz )
( cd usr/info ; rm -rf sc-1.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/sc-1.gz sc-1.gz )
( cd usr/info ; rm -rf sc-2.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/sc-2.gz sc-2.gz )
( cd usr/info ; rm -rf sc-3.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/sc-3.gz sc-3.gz )
( cd usr/info ; rm -rf vip.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/vip.gz vip.gz )
( cd usr/info ; rm -rf vip-1.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/vip-1.gz vip-1.gz )
( cd usr/info ; rm -rf vip-2.gz )
( cd usr/info ; ln -sf /cdrom/live/usr/info/vip-2.gz vip-2.gz )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf AT386.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/AT386.el AT386.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf README )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/README README )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf apollo.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/apollo.el apollo.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf apollo.elc )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/apollo.elc apollo.elc )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf bg-mouse.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/bg-mouse.el bg-mouse.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf bg-mouse.elc )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/bg-mouse.elc bg-mouse.elc )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf bobcat.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/bobcat.el bobcat.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf internal.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/internal.el internal.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf keyswap.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/keyswap.el keyswap.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf lk201.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/lk201.el lk201.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf news.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/news.el news.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf news.elc )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/news.elc news.elc )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf sun-curs.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/sun-curs.el sun-curs.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf sun-fns.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/sun-fns.el sun-fns.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf sun-mouse.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/sun-mouse.el sun-mouse.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf sun-mouse.elc )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/sun-mouse.elc sun-mouse.elc )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf sun.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/sun.el sun.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf sun.elc )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/sun.elc sun.elc )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf sup-mouse.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/sup-mouse.el sup-mouse.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf sup-mouse.elc )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/sup-mouse.elc sup-mouse.elc )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf tvi970.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/tvi970.el tvi970.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf tvi970.elc )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/tvi970.elc tvi970.elc )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt100-led.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt100-led.el vt100-led.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt100-led.elc )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt100-led.elc vt100-led.elc )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt100.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt100.el vt100.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt100.elc )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt100.elc vt100.elc )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt102.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt102.el vt102.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt125.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt125.el vt125.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt200.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt200.el vt200.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt200.elc )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt200.elc vt200.elc )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt201.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt201.el vt201.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt220.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt220.el vt220.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt240.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt240.el vt240.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt300.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt300.el vt300.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt320.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt320.el vt320.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt400.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt400.el vt400.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf vt420.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/vt420.el vt420.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf wyse50.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/wyse50.el wyse50.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf wyse50.elc )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/wyse50.elc wyse50.elc )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf x-win.el )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/x-win.el x-win.el )
( cd usr/lib/emacs/19.28/lisp/term ; rm -rf x-win.elc )
( cd usr/lib/emacs/19.28/lisp/term ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/term/x-win.elc x-win.elc )
( cd usr/lib/emacs/19.28/lisp ; rm -rf abbrevlist.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/abbrevlist.el abbrevlist.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf blessmail.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/blessmail.el blessmail.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf cal-menu.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/cal-menu.el cal-menu.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf cdl.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/cdl.el cdl.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf cl-specs.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/cl-specs.el cl-specs.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf foldout.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/foldout.el foldout.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf iso-transl.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/iso-transl.el iso-transl.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf ispell4.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/ispell4.el ispell4.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf loaddefs.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/loaddefs.el loaddefs.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf loadup.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/loadup.el loadup.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf paths.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/paths.el paths.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf sc.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/sc.el sc.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf tpu-doc.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/tpu-doc.el tpu-doc.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf version.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/version.el version.el )
( cd usr/lib/emacs/19.28/lisp ; rm -rf vt-control.el )
( cd usr/lib/emacs/19.28/lisp ; ln -sf /cdrom/live/usr/lib/emacs/19.28/lisp/vt-control.el vt-control.el )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf test-distrib )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/test-distrib test-distrib )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf make-path )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/make-path make-path )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf wakeup )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/wakeup wakeup )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf profile )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/profile profile )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf make-docfile )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/make-docfile make-docfile )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf digest-doc )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/digest-doc digest-doc )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf sorted-doc )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/sorted-doc sorted-doc )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf movemail )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/movemail movemail )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf cvtmail )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/cvtmail cvtmail )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf fakemail )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/fakemail fakemail )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf yow )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/yow yow )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf emacsserver )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/emacsserver emacsserver )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf hexl )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/hexl hexl )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf timer )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/timer timer )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf rcs2log )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/rcs2log rcs2log )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; rm -rf vcdiff )
( cd usr/lib/emacs/19.28/i486-slackware-linux ; ln -sf /cdrom/live/usr/lib/emacs/19.28/i486-slackware-linux/vcdiff vcdiff )
( cd usr/doc/emacs-19.28 ; rm -rf GETTING.GNU.SOFTWARE )
( cd usr/doc/emacs-19.28 ; ln -sf /cdrom/live/usr/doc/emacs-19.28/GETTING.GNU.SOFTWARE GETTING.GNU.SOFTWARE )
( cd usr/doc/emacs-19.28 ; rm -rf INSTALL )
( cd usr/doc/emacs-19.28 ; ln -sf /cdrom/live/usr/doc/emacs-19.28/INSTALL INSTALL )
( cd usr/doc/emacs-19.28 ; rm -rf PROBLEMS )
( cd usr/doc/emacs-19.28 ; ln -sf /cdrom/live/usr/doc/emacs-19.28/PROBLEMS PROBLEMS )
( cd usr/doc/emacs-19.28 ; rm -rf README )
( cd usr/doc/emacs-19.28 ; ln -sf /cdrom/live/usr/doc/emacs-19.28/README README )
( cd usr/man/preformat/cat1 ; rm -rf emacs.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/emacs.1.gz emacs.1.gz )
( cd usr/man/preformat/cat1 ; rm -rf etags.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/etags.1.gz etags.1.gz )
